ServerErrorKind

Enum ServerErrorKind 

#[non_exhaustive]
pub enum ServerErrorKind {
Show 14 variants ResponseError, ExecAbort, BusyLoading, NoScript, Moved, Ask, TryAgain, ClusterDown, CrossSlot, MasterDown, ReadOnly, NotBusy, NoSub, NoPerm,
}
Kinds of errors returned from the server

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ResponseError

The server generated an invalid response, or returned a general error.



ExecAbort

A script execution was aborted.



BusyLoading

The server cannot response because it’s loading a dump.



NoScript

A script that was requested does not actually exist.



Moved

Raised if a key moved to a different node.



Ask

Raised if a key moved to a different node but we need to ask.



TryAgain

Raised if a request needs to be retried.



ClusterDown

Raised if a redis cluster is down.



CrossSlot

A request spans multiple slots



MasterDown

A cluster master is unavailable.



ReadOnly

Attempt to write to a read-only server



NotBusy

Attempted to kill a script/function while they werent’ executing



NoSub

Attempted to unsubscribe on a connection that is not in subscribed mode.



NoPerm

Attempted to use a command without ACL permission.