#[non_exhaustive]pub enum ValueType {
Show 18 variants
None,
String,
List,
Set,
ZSet,
Hash,
Stream,
VectorSet,
JSON,
BloomFilterRedis,
CuckooFilter,
CountMin,
TDigest,
TopK,
TimeSeries,
Trie,
BloomFilterValKey,
Unknown(String),
}Expand description
Possible types of value held in Redis: Redis Docs
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
Key does not have a value
String
Generally returned by anything that returns a single element. Redis Docs
List
A list of String values. Redis Docs
Set
A set of unique String values. Redis Docs
ZSet
A sorted set of String values. Redis Docs
Hash
A collection of field-value pairs. Redis Docs
Stream
A Redis Stream. Redis Docs
VectorSet
A vector set. Redis Docs
JSON
A RedisJSON value. Redis Docs
BloomFilterRedis
A Bloom filter from Redis’ module. Redis Docs
CuckooFilter
A Cuckoo filter. Redis Docs
CountMin
A Count-min. Redis Docs
TDigest
A t-Digest. Redis Docs
TopK
A Top-K. Redis Docs
TimeSeries
A time series. Redis Docs
Trie
A Trie. Redis Docs
BloomFilterValKey
A Bloom filter from Valkey’s module. ValKey Docs
Unknown(String)
Any other value type not explicitly defined in Redis Docs