#[non_exhaustive]pub enum RetryMethod {
Reconnect,
NoRetry,
RetryImmediately,
WaitAndRetry,
AskRedirect,
MovedRedirect,
ReconnectFromInitialConnections,
}Expand description
What method should be used if retrying this request.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Reconnect
Create a fresh connection, since the current connection is no longer usable.
NoRetry
Don’t retry, this is a permanent error.
RetryImmediately
Retry immediately, this doesn’t require a wait.
WaitAndRetry
Retry after sleeping to avoid overloading the external service.
AskRedirect
The key has moved to a different node but we have to ask which node, this is only relevant for clusters.
MovedRedirect
The key has moved to a different node, this is only relevant for clusters.
ReconnectFromInitialConnections
Reconnect the initial connection to the master cluster, this is only relevant for clusters.